==> openwebmail-2.10.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/zh_CN.GB2312/htmlarea-lang.js <==
// I18N constants

// Please translate the following part for your language
// 1. the left  side of fontname, font size and formatblock
// 2. the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 )":  "1",
		"2 (10 )": "2",
		"3 (12 )": "3",
		"4 (14 )": "4",
		"5 (18 )": "5",
		"6 (24 )": "6",
		"7 (36 )": "7"
	},

	formatblock: {
		" 1": "h1",
		" 2": "h2",
		" 3": "h3",
		" 4": "h4",
		" 5": "h5",
		" 6": "h6",
		"": "p",
		"λַ": "address",
		"Ѹʽ": "pre"
	},

	tooltips: {
		bold:           "",
		italic:         "б",
		underline:      "",
		strikethrough:  "ɾ",
		subscript:      "±",
		superscript:    "ϱ",
		justifyleft:    "",
		justifycenter:  "",
		justifyright:   "Ҷ",
		justifyfull:    "Ҷ",
		orderedlist:    "Ŀ",
		unorderedlist:  "ޱĿ",
		outdent:        "",
		indent:         "",
		forecolor:      "ɫ",
		backcolor:      "ɫ",
		horizontalrule: "ˮƽָ",
		createlink:     "볬",
		insertimage:    "ͼƬ",
		insertsound:    "",
		inserttable:    "",
		htmlmode:       "л HTML ģʽ",
		popupeditor:    "Ŵ༭",
		about:          "",
		help:           "",
		textindicator:  "Ŀǰʽ"
	}
};

==> openwebmail-2.51p2.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/zh_CN.GB2312/htmlarea-lang.js <==
// I18N constants

// Please translate the following part for your language
// 1. the left  side of fontname, font size and formatblock
// 2. the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 )":  "1",
		"2 (10 )": "2",
		"3 (12 )": "3",
		"4 (14 )": "4",
		"5 (18 )": "5",
		"6 (24 )": "6",
		"7 (36 )": "7"
	},

	formatblock: {
		" 1": "h1",
		" 2": "h2",
		" 3": "h3",
		" 4": "h4",
		" 5": "h5",
		" 6": "h6",
		"": "p",
		"λַ": "address",
		"Ѹʽ": "pre"
	},

	tooltips: {
		bold:           "",
		italic:         "б",
		underline:      "",
		strikethrough:  "ɾ",
		subscript:      "±",
		superscript:    "ϱ",
		justifyleft:    "",
		justifycenter:  "",
		justifyright:   "Ҷ",
		justifyfull:    "Ҷ",
		insertorderedlist:    "Ŀ",
		insertunorderedlist:  "ޱĿ",
		outdent:        "",
		indent:         "",
		forecolor:      "ɫ",
		hilitecolor:    "ɫ",
		inserthorizontalrule: "ˮƽָ",
		createlink:     "볬",
		insertimage:    "ͼƬ",
		insertsound:    "",
		inserttable:    "",
		htmlmode:       "л HTML ģʽ",
		popupeditor:    "Ŵ༭",
		about:          "",
		showhelp:       "",
		textindicator:  "Ŀǰʽ",
		undo:           "_",
		redo:           "_",
		cut:            "ŤU",
		copy:           "ƻs",
		paste:          "KW"
	},

	buttons: {
		"ok":           "ȷ",
		"cancel":       "ȡ"
	},

	msg: {
		"Path":         "·",
		"TEXT_MODE":    "ڿ HTML żԭʼ. 밴 [<>] ťص HTML ༭ģʽ."
	}
};
